package net.knarcraft.paidsigns.property;

/**
 * A representation of a paid sign's editable properties
 */
public enum PaidSignProperty {

    /**
     * The name of a paid sign
     */
    NAME("name"),

    /**
     * The cost of creating a sign matching the paid sign
     */
    COST("cost"),

    /**
     * The permission required to create the plugin sign matching the paid sign
     */
    PERMISSION("permission"),

    /**
     * Whether to ignore case for any sign conditions added to the sign
     */
    IGNORE_CASE("ignoreCase"),

    /**
     * Whether to ignore color for any sign conditions added to the sign
     */
    IGNORE_COLOR("ignoreColor"),

    /**
     * Whether to treat a single condition match as a full match
     */
    MATCH_ANY_CONDITION("matchAnyCondition");

    private final String stringRepresentation;

    /**
     * Instantiates a new paid sign property
     *
     * @param stringRepresentation <p>The string representation of the paid sign property</p>
     */
    PaidSignProperty(String stringRepresentation) {
        this.stringRepresentation = stringRepresentation;
    }

    /**
     * Gets the string representation of this paid sign property
     *
     * @return <p>The string representation of this paid sign property</p>
     */
    public String getStringRepresentation() {
        return this.stringRepresentation;
    }

    /**
     * Gets the paid sign property matching the given string
     *
     * @param propertyString <p>The string representing a paid sign property</p>
     * @return <p>The matching paid sign property, or null if no such property exists</p>
     */
    public static PaidSignProperty getFromString(String propertyString) {
        for (PaidSignProperty paidSignProperty : PaidSignProperty.values()) {
            if (paidSignProperty.getStringRepresentation().equalsIgnoreCase(propertyString)) {
                return paidSignProperty;
            }
        }
        return null;
    }

}
